/* Algorithm.java
 *
 * created: Tue Dec 15 1998
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1998,1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/diana/plot/Algorithm.java,v 1.5 1999/03/22 11:00:37 kmr Exp $
 */

package diana.plot;

/**
 *  This class represents an algorithm that can be plotted.
 *
 *  @author Kim Rutherford
 *  @version $Id: Algorithm.java,v 1.5 1999/03/22 11:00:37 kmr Exp $
 **/

public abstract class Algorithm {
  /**
   *  Create a new Algorithm object.
   *  @param strand The strand to do the calculation on.
   *  @param algorithm_name A String used to identify this algorithm to the
   *    user.
   **/
  public Algorithm (String algorithm_name) {
    this.algorithm_name = algorithm_name;
  }

  /**
   *  Return the name of this algorithm.
   **/
  public String getAlgorithmName () {
     return algorithm_name;
  }

  /**
   *  Return the default or optimal window size.
   *  @return null is returned if this algorithm doesn't have optimal window
   *    size.
   **/
  public Integer getDefaultWindowSize () {
    return null;
  } 

    /**
   *  Return the default maximum window size for this algorithm.
   *  @return null is returned if this algorithm doesn't have maximum window
   *    size.
   **/
  public Integer getDefaultMaxWindowSize () {
    return null;
  } 

  /**
   *  Return the default minimum window size for this algorithm.
   *  @return null is returned if this algorithm doesn't have minimum window
   *    size.
   **/
  public Integer getDefaultMinWindowSize () {
    return null;
  } 

  /**
   *  Return the default or optimal step size.
   *  @return null is returned if this algorithm doesn't have optimal step
   *    size.
   **/
  public Integer getDefaultStepSize (int window_size) {
    return null;
  } 

  /**
   *  Return the maximum value of this algorithm.
   *  @return null is returned if this algorithm doesn't have a fixed maximum.
   **/
  public Float getMaximum () {
    return null;
  } 

  /**
   *  Return the minimum value of this algorithm.
   *  @return null is returned if this algorithm doesn't have a fixed minimum.
   **/
  public Float getMinimum () {
    return null;
  } 

  /**
   *  Return the average value of function over the whole strand.
   *  @return null is returned if this algorithm doesn't have an average or if
   *    the average can't be calculated.
   **/
  public Float getAverage () {
    return null;
  }

  /**
   *  The name of this algorithm, as passed to the constructor.
   **/
  private String algorithm_name;
}
