/* Unknown.java
 *
 * created: Mon Oct 12 1998
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1998,1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/uk/ac/sanger/pathogens/embl/Unknown.java,v 1.2 1999/06/16 15:02:47 kmr Exp $
 */

package uk.ac.sanger.pathogens.embl;

import java.io.IOException;
import java.io.Writer;

/**
 *  This class is used to store EMBL lines that are not handled by other
 *  classes.
 *
 *  @author Kim Rutherford
 *  @version $Id: Unknown.java,v 1.2 1999/06/16 15:02:47 kmr Exp $
 **/

public class Unknown extends LineGroup {
  /**
   *  Create a new Unknown object.  One line is read from the in_stream and
   *  stored.
   **/
  public Unknown (LinePushBackReader in_stream)
      throws IOException {
    line = in_stream.readLine ();
  }

  /**
   *  Return the line the read from the input stream.
   **/
  public String getLine () {
    return line;
  }

  /**
   *  Write the line stored in this Unknown object to the given stream.  The
   *  output will be in EMBL format (but see the diana_extensions argument).
   *  @param writer The stream to write to.
   *  @param diana_extensions If true then the any diana additions to the embl
   *    file format will be included in the output, otherwise they will be
   *    removed.
   **/
  public void writeToStream (final Writer writer,
                             final boolean diana_extensions)
      throws IOException {
    
    writer.write (toString ());
  }

  /**
   *  Return this LineGroup object as a String.
   **/
  public String toString () {
    return getLine () + "\n";
  }

  /**
   *  Return the type of this LineGroup object (SEQUENCE, FEATURE_TABLE, etc.)
   *  Returns UNKNOWN for objects of this class.
   **/
  public int getType () {
    return UNKNOWN;
  }
  
  /**
   *  The unknown line.
   **/
  private String line;
}


